@@ -1,5 +1,7 @@
 """Tests of gitinfo.py"""
 
+import re
+
 from scriv.gitinfo import current_branch_name, get_github_repo, user_nick
 
 
@@ -39,6 +41,11 @@ def test_get_github_repo_one_github_remote(fake_git):
     assert get_github_repo() == "joe/myproject"
 
 
+def test_get_github_repo_one_github_remote_no_extension(fake_git):
+    fake_git.add_remote("mygithub", "git@github.com:joe/myproject")
+    assert get_github_repo() == "joe/myproject"
+
+
 def test_get_github_repo_two_github_remotes(fake_git):
     fake_git.add_remote("mygithub", "git@github.com:joe/myproject.git")
     fake_git.add_remote("upstream", "git@github.com:psf/myproject.git")
@@ -58,4 +65,10 @@ def test_get_github_repo_no_github_remotes(fake_git):
 
 
 def test_real_get_github_repo():
-    assert get_github_repo() == "nedbat/scriv"
+    # Since we don't know the name of this repo (forks could be anything),
+    # we can't be sure what we get, except it should be word/word, and not end
+    # with .git
+    repo = get_github_repo()
+    assert repo is not None
+    assert re.fullmatch(r"\w+/\w+", repo)
+    assert not repo.endswith(".git")
